#include "server_data_interact.h"

#include <engine_engine_number_9/baza_throw.h>
#include <engine_engine_number_9/http_structures/cookies.h>

namespace iu9cawebchat {
    const char* stringify_user_chat_role(int64_t role) {
        if (role == user_chat_role_admin)
            return "admin";
        if (role == user_chat_role_regular)
            return "regular";
        if (role == user_chat_role_read_only)
            return "read-only";
        return "not-a-member";
    }

    int64_t find_user_by_credentials (SqliteConnection& conn, const std::string& nickname, const std::string& password) {
        SqliteStatement sql_req(conn,
            "SELECT `id` FROM `user` WHERE `nickname` = ?1 AND `password` = ?2",
            {}, {{1, nickname}, {2, password}});
        fsql_integer_or_null id_col;
        int status = sqlite_stmt_step(sql_req, {{0, &id_col}}, {});
        if (status == SQLITE_ROW) {
            een9_ASSERT_pl(id_col.exist & id_col.value >= 0);
            return id_col.value;
        }
        return -1;
    }

    std::string find_user_name (SqliteConnection& conn, int64_t uid) {
        een9_ASSERT(uid >= 0, "Are you crazy?");
        SqliteStatement sql_req(conn,
           "SELECT `name` FROM `user` WHERE `id` = ?1",
           {{1, uid}}, {});
        fsql_text8_or_null name_col;
        int status = sqlite_stmt_step(sql_req, {}, {{0, &name_col}});
        if (status == SQLITE_ROW) {
            een9_ASSERT_pl(name_col.exist);
            return name_col.value;
        }
        een9_THROW("No such user");
    }

    RowUser_Content lookup_user_content(SqliteConnection &conn, int64_t uid) {
        een9_ASSERT(uid >= 0, "Are you crazy?");
        SqliteStatement sql_req(conn,
           "SELECT `nickname`, `name` FROM `user` WHERE `id` = ?1",
           {{1, uid}}, {});
        fsql_text8_or_null nickname_col;
        fsql_text8_or_null name_col;
        int status = sqlite_stmt_step(sql_req, {}, {{0, &nickname_col}, {1, &name_col}});
        if (status == SQLITE_ROW) {
            return {std::move(nickname_col.value), std::move(name_col.value)};
        }
        een9_THROW("No such user");
    }

    RowChat_Content lookup_chat_content(SqliteConnection &conn, int64_t chatId) {
        een9_ASSERT(chatId >= 0, "Are you crazy?");
        SqliteStatement sql_req(conn,
           "SELECT `nickname`, `name`, `lastMsgId` FROM `chat` WHERE `id` = ?1",
           {{1, chatId}}, {});
        fsql_text8_or_null nickname_col;
        fsql_text8_or_null name_col;
        fsql_integer_or_null last_msg_id_col;
        int status = sqlite_stmt_step(sql_req, {{2, &last_msg_id_col}}, {{0, &nickname_col}, {1, &name_col}});
        if (status == SQLITE_ROW) {
            return {std::move(nickname_col.value), std::move(name_col.value),
                last_msg_id_col.exist ? last_msg_id_col.value : -1};
        }
        een9_THROW("No such chat");
    }

    RowMessage_Content lookup_message_content(SqliteConnection& conn, int64_t chatId, int64_t msgId) {
        SqliteStatement req(conn,
            "SELECT `previousId`, `senderUserId`, `exists`, `isSystem`, `text` FROM `message` WHERE "
            "`chatId` = ?1 AND `id` = ?2", {{1, chatId}, {2, msgId}}, {});
        fsql_integer_or_null previousId, senderUserId, exists, isSystem;
        fsql_text8_or_null msg_text;
        int status = sqlite_stmt_step(req, {{0, &previousId}, {1, &senderUserId}, {2, &exists}, {3, &isSystem}},
            {{4, &msg_text}});
        if (status == SQLITE_ROW) {
            return {(bool)isSystem.value, msg_text.value, senderUserId.exist ? senderUserId.value : -1,
            previousId.exist ? previousId.value : -1};
        }
        een9_THROW("No such message");
    }

    int64_t get_role_of_user_in_chat(SqliteConnection& conn, int64_t userId, int64_t chatId) {
        SqliteStatement req(conn,
            "SELECT `role` FROM `user_chat_membership` WHERE `userId` = ?1 AND `chatId` = ?2",
            {{1, userId}, {2, chatId}}, {});
        fsql_integer_or_null role;
        int status = sqlite_stmt_step(req, {{0, &role}}, {});
        if (status == SQLITE_ROW) {
            return role.exist ? (int)role.value : user_chat_role_deleted;
        }
        return user_chat_role_deleted;
    }

    /* All the api calls processing is done in dedicated files */
}
